@@ -1,24 +1,30 @@
 from __future__ import division
-from past.utils import old_div
+
 import collections
+from typing import Any, Dict, List, Optional, Union
 
 import astropy.units as u
+import numba as nb
 import numpy
 import scipy.integrate
+from past.utils import old_div
 
+from astromodels.core.memoization import use_astromodels_memoization
+from astromodels.core.parameter import Parameter
 from astromodels.core.sky_direction import SkyDirection
 from astromodels.core.spectral_component import SpectralComponent
 from astromodels.core.tree import Node
 from astromodels.core.units import get_units
-from astromodels.sources.source import Source, POINT_SOURCE
+from astromodels.functions.function import Function1D
+from astromodels.sources.source import Source, SourceType
+from astromodels.utils.logging import setup_logger
 from astromodels.utils.pretty_list import dict_to_list
-from astromodels.core.memoization import use_astromodels_memoization
 
 __author__ = 'giacomov'
 
-
 __all__ = ["PointSource"]
 
+log = setup_logger(__name__)
 
 class PointSource(Source, Node):
     """
@@ -55,9 +61,15 @@ class PointSource(Source, Node):
     :param sky_position: an instance of SkyDirection
     :return:
     """
-
-    def __init__(self, source_name, ra=None, dec=None, spectral_shape=None,
-                 l=None, b=None, components=None, sky_position=None):
+    def __init__(self,
+                 source_name: str,
+                 ra: Optional[float] = None,
+                 dec: Optional[float] = None,
+                 spectral_shape: Optional[Function1D] = None,
+                 l: Optional[float] = None,
+                 b: Optional[float] = None,
+                 components=None,
+                 sky_position: Optional[SkyDirection]=None):
 
         # Check that we have all the required information
 
@@ -65,9 +77,15 @@ class PointSource(Source, Node):
 
         # Check that we have one and only one specification of the position
 
-        assert ((ra is not None and dec is not None) ^
+        if not ((ra is not None and dec is not None) ^
                 (l is not None and b is not None) ^
-                (sky_position is not None)), "You have to provide one and only one specification for the position"
+                (sky_position is not None)):
+
+            log.error(
+                "You have to provide one and only one specification for the position"
+            )
+
+            raise AssertionError()
 
         # Gather the position
 
@@ -84,8 +102,10 @@ class PointSource(Source, Node):
 
                 except (TypeError, ValueError):
 
-                    raise AssertionError("RA and Dec must be numbers. If you are confused by this message, you "
+                    log.error("RA and Dec must be numbers. If you are confused by this message, you "
                                          "are likely using the constructor in the wrong way. Check the documentation.")
+                    
+                    raise AssertionError()
 
                 sky_position = SkyDirection(ra=ra, dec=dec)
 
@@ -93,16 +113,18 @@ class PointSource(Source, Node):
 
                 sky_position = SkyDirection(l=l, b=b)
 
-        self._sky_position = sky_position
+        self._sky_position: SkyDirection = sky_position
 
         # Now gather the component(s)
 
         # We need either a single component, or a list of components, but not both
         # (that's the ^ symbol)
 
-        assert (spectral_shape is not None) ^ (components is not None), "You have to provide either a single " \
-                                                                        "component, or a list of components " \
-                                                                        "(but not both)."
+        if not (spectral_shape is not None) ^ (components is not None):
+
+            log.error("You have to provide either a single component, or a list of components (but not both).")
+
+            raise AssertionError()
 
         # If the user specified only one component, make a list of one element with a default name ("main")
 
@@ -110,7 +132,7 @@ class PointSource(Source, Node):
 
             components = [SpectralComponent("main", spectral_shape)]
 
-        Source.__init__(self, components, POINT_SOURCE)
+        Source.__init__(self, components, src_type=SourceType.POINT_SOURCE)
 
         # A source is also a Node in the tree
 
@@ -164,9 +186,9 @@ class PointSource(Source, Node):
                 # Fast version without units, where x is supposed to be in the same units as currently defined in
                 # units.get_units()
 
-                results = [component.shape(x) for component in list(self.components.values())]
+                results = numpy.array([component.shape(x) for component in list(self.components.values())])
 
-                return numpy.sum(results, 0)
+                return _sum(results)
 
         else:
 
@@ -213,7 +235,7 @@ class PointSource(Source, Node):
 
                 return old_div(integrals, (b - a))
 
-    def has_free_parameters(self):
+    def has_free_parameters(self) -> bool:
         """
         Returns True or False whether there is any parameter in this source
 
@@ -237,7 +259,7 @@ class PointSource(Source, Node):
         return False
 
     @property
-    def free_parameters(self):
+    def free_parameters(self) -> Dict[str, Parameter]:
         """
         Returns a dictionary of free parameters for this source.
         We use the parameter path as the key because it's 
@@ -264,7 +286,7 @@ class PointSource(Source, Node):
         return free_parameters
 
     @property
-    def parameters(self):
+    def parameters(self) -> Dict[str, Parameter]:
         """
         Returns a dictionary of all parameters for this source.
         We use the parameter path as the key because it's 
@@ -310,3 +332,9 @@ class PointSource(Source, Node):
 
         return dict_to_list(repr_dict, rich_output)
 
+
+
+@nb.njit(fastmath=True)
+def _sum(x):
+    return numpy.sum(x, axis=0)
+    
